==> foundation-multi-hashing-0.0.6.tgz: package/README.md <==
# Foundation Multi-Hashing

[![Foundation CI](https://github.com/blinkhash/foundation-multi-hashing/actions/workflows/build.yml/badge.svg?branch=master)](https://github.com/blinkhash/foundation-multi-hashing/actions/workflows/build.yml)
[![License: GPL v2](https://img.shields.io/badge/License-GPL%20v2-blue.svg)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html)
[![Downloads](https://img.shields.io/npm/dm/foundation-multi-hashing.svg)](https://www.npmjs.com/package/foundation-multi-hashing)
[![Version](https://img.shields.io/npm/v/foundation-multi-hashing.svg)](https://www.npmjs.com/package/foundation-multi-hashing)
[![Known Vulnerabilities](https://snyk.io/test/npm/foundation-multi-hashing/badge.svg)](https://snyk.io/test/npm/foundation-multi-hashing)
[![Discord](https://img.shields.io/discord/738590795384356904)](https://discord.gg/8xtHZFKJQY)

This repository is a collection of hashing algorithms that are currently supported by Foundation. Each of these algorithms are leveraged by [foundation-stratum](https://github.com/blinkhash/foundation-stratum), which handles the majority of the mining process. To request for an unsupported algorithm to be added, open an issue or pull request and it will be addressed.  

#### Need Support?

If you need help with a code-related matter, the first place to look is our [Discord](https://discord.gg/8xtHZFKJQY), where the developers will be available to answer any questions. However, please do not come to me with issues regarding setup. Use Google and the existing documentation for that.

---

### Credits

* [NSA](http://www.nsa.gov/) and [NIST](http://www.nist.gov/) for creation or sponsoring creation of SHA2 and SHA3 algos
* [Keccak](http://en.wikipedia.org/wiki/Keccak) - Guido Bertoni, Joan Daemen, Michaël Peeters, and Gilles Van Assche
* [Skein](http://en.wikipedia.org/wiki/Skein_(hash_function)) - Bruce Schneier, Stefan Lucks, Niels Ferguson, Doug Whiting, Mihir Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
* [BLAKE](http://en.wikipedia.org/wiki/BLAKE_(hash_function)) - Jean-Philippe Aumasson, Luca Henzen, Willi Meier, and Raphael C.-W. Phan
* [Grøstl](http://en.wikipedia.org/wiki/Gr%C3%B8stl) - Praveen Gauravaram, Lars Knudsen, Krystian Matusiewicz, Florian Mendel, Christian Rechberger, Martin Schläffer, and Søren S. Thomsen
* [JH](http://en.wikipedia.org/wiki/JH_(hash_function)) - Hongjun Wu
* [Fugue](http://en.wikipedia.org/wiki/Fugue_(hash_function)) - Shai Halevi, William E. Hall, and Charanjit S. Jutla
* [scrypt](http://en.wikipedia.org/wiki/Scrypt) - Colin Percival
* [bcrypt](http://en.wikipedia.org/wiki/Bcrypt) - Niels Provos and David Mazières
* [X11](http://www.darkcoin.io/), [Hefty1](http://heavycoin.github.io/about.html), [Quark](http://www.qrk.cc/) creators (they just mixed together a bunch of the above algos)
* Any developers not mentioned who worked on the algorithms included in this repository

---

### Donations

Maintaining this project has always been driven out of nothing more than a desire to give back to the mining community, however I always appreciate donations, especially if this repository helps you in any way.

- Bitcoin: 3EbrVYLxN5WeQmPpL6owo3A7rJELXecbbc
- Ethereum: 0xd3e3daED621d228244Fa89A3dd8AF07B52E72319
- Litecoin: MFWpARrSADAy3Qj79C4pSasS9F156QipwC
- ZCash: t1NSk8gyiou8TxWRZTVuUkfM5f9riopN58A

---

### License

Released under the GNU General Public License v2. See http://www.gnu.org/licenses/gpl-2.0.html for more information

---

==> foundation-multi-hashing-0.1.1.tgz: package/README.md <==
# Foundation Multi-Hashing

[![Foundation CI](https://github.com/blinkhash/foundation-multi-hashing/actions/workflows/build.yml/badge.svg?branch=master)](https://github.com/blinkhash/foundation-multi-hashing/actions/workflows/build.yml)
[![License: GPL v2](https://img.shields.io/badge/License-GPL%20v2-blue.svg)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html)
[![Downloads](https://img.shields.io/npm/dm/foundation-multi-hashing.svg)](https://www.npmjs.com/package/foundation-multi-hashing)
[![Version](https://img.shields.io/npm/v/foundation-multi-hashing.svg)](https://www.npmjs.com/package/foundation-multi-hashing)
[![Known Vulnerabilities](https://snyk.io/test/npm/foundation-multi-hashing/badge.svg)](https://snyk.io/test/npm/foundation-multi-hashing)
[![Discord](https://img.shields.io/discord/738590795384356904)](https://discord.gg/rNjez6VgNF)

This repository is a collection of hashing algorithms that are currently supported by Foundation. Each of these algorithms are leveraged by [foundation-stratum](https://github.com/blinkhash/foundation-stratum), which handles the majority of the mining process. To request for an unsupported algorithm to be added, open an issue or pull request and it will be addressed.  

#### Need Support?

If you need help with a code-related matter, the first place to look is our [Discord](https://discord.gg/rNjez6VgNF), where the developers will be available to answer any questions. However, please do not come to me with issues regarding setup. Use Google and the existing documentation for that.

---

### Credits

* [NSA](http://www.nsa.gov/) and [NIST](http://www.nist.gov/) for creation or sponsoring creation of SHA2 and SHA3 algos
* [Keccak](http://en.wikipedia.org/wiki/Keccak) - Guido Bertoni, Joan Daemen, Michaël Peeters, and Gilles Van Assche
* [Skein](http://en.wikipedia.org/wiki/Skein_(hash_function)) - Bruce Schneier, Stefan Lucks, Niels Ferguson, Doug Whiting, Mihir Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
* [BLAKE](http://en.wikipedia.org/wiki/BLAKE_(hash_function)) - Jean-Philippe Aumasson, Luca Henzen, Willi Meier, and Raphael C.-W. Phan
* [Grøstl](http://en.wikipedia.org/wiki/Gr%C3%B8stl) - Praveen Gauravaram, Lars Knudsen, Krystian Matusiewicz, Florian Mendel, Christian Rechberger, Martin Schläffer, and Søren S. Thomsen
* [JH](http://en.wikipedia.org/wiki/JH_(hash_function)) - Hongjun Wu
* [Fugue](http://en.wikipedia.org/wiki/Fugue_(hash_function)) - Shai Halevi, William E. Hall, and Charanjit S. Jutla
* [scrypt](http://en.wikipedia.org/wiki/Scrypt) - Colin Percival
* [bcrypt](http://en.wikipedia.org/wiki/Bcrypt) - Niels Provos and David Mazières
* [X11](http://www.darkcoin.io/), [Hefty1](http://heavycoin.github.io/about.html), [Quark](http://www.qrk.cc/) creators (they just mixed together a bunch of the above algos)
* Any developers not mentioned who worked on the algorithms included in this repository

---

### Donations

Maintaining this project has always been driven out of nothing more than a desire to give back to the mining community, however I always appreciate donations, especially if this repository helps you in any way.

- Bitcoin: 3EbrVYLxN5WeQmPpL6owo3A7rJELXecbbc
- Ethereum: 0xd3e3daED621d228244Fa89A3dd8AF07B52E72319
- Litecoin: MFWpARrSADAy3Qj79C4pSasS9F156QipwC
- ZCash: t1NSk8gyiou8TxWRZTVuUkfM5f9riopN58A

---

### License

Released under the GNU General Public License v2. See http://www.gnu.org/licenses/gpl-2.0.html for more information

---
